
Welcome to deep_translator's documentation!
======================================

If you see this doc in other languages,you can see :doc:`Choose languages</other_lang>`. 

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :name: mastertoc

   readme
   installation
   usage
   modules
   contributing
   authors
   history
   other_lang

.. toctree::
   :hidden:

   ja/index
   
Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
